@@ -15,53 +15,21 @@
 import os
 import shutil
 
-from oslo_config import cfg
 from oslo_log import log as oslo_logging
 
+from cloudbaseinit import conf as cloudbaseinit_conf
+from cloudbaseinit import constant
 from cloudbaseinit import exception
 from cloudbaseinit.metadata.services import base
 from cloudbaseinit.metadata.services import baseopenstackservice
 from cloudbaseinit.metadata.services.osconfigdrive import factory
 
-
-# Config Drive types and possible locations.
-CD_TYPES = {
-    "vfat",    # Visible device (with partition table).
-    "iso",     # "Raw" format containing ISO bytes.
-}
-CD_LOCATIONS = {
-    # Look into optical units devices. Only an ISO format could
-    # be used here (vfat ignored).
-    "cdrom",
-    # Search through physical disks for raw ISO content or vfat filesystems
-    # containing configuration drive's content.
-    "hdd",
-    # Search through partitions for raw ISO content or through volumes
-    # containing configuration drive's content.
-    "partition",
-}
-
-opts = [
-    cfg.BoolOpt('config_drive_raw_hhd', default=True,
-                help='Look for an ISO config drive in raw HDDs',
-                deprecated_for_removal=True),
-    cfg.BoolOpt('config_drive_cdrom', default=True,
-                help='Look for a config drive in the attached cdrom drives',
-                deprecated_for_removal=True),
-    cfg.BoolOpt('config_drive_vfat', default=True,
-                help='Look for a config drive in VFAT filesystems',
-                deprecated_for_removal=True),
-    cfg.ListOpt('config_drive_types', default=list(CD_TYPES),
-                help='Supported formats of a configuration drive'),
-    cfg.ListOpt('config_drive_locations', default=list(CD_LOCATIONS),
-                help='Supported configuration drive locations'),
-]
-
-CONF = cfg.CONF
-CONF.register_opts(opts)
-
+CONF = cloudbaseinit_conf.CONF
 LOG = oslo_logging.getLogger(__name__)
 
+CD_TYPES = constant.CD_TYPES
+CD_LOCATIONS = constant.CD_LOCATIONS
+
 
 class ConfigDriveService(baseopenstackservice.BaseOpenStackService):
 
@@ -70,17 +38,17 @@ class ConfigDriveService(baseopenstackservice.BaseOpenStackService):
         self._metadata_path = None
 
     def _preprocess_options(self):
-        self._searched_types = set(CONF.config_drive_types)
-        self._searched_locations = set(CONF.config_drive_locations)
+        self._searched_types = set(CONF.config_drive.types)
+        self._searched_locations = set(CONF.config_drive.locations)
 
         # Deprecation backward compatibility.
-        if CONF.config_drive_raw_hhd:
+        if CONF.config_drive.raw_hdd:
             self._searched_types.add("iso")
             self._searched_locations.add("hdd")
-        if CONF.config_drive_cdrom:
+        if CONF.config_drive.cdrom:
             self._searched_types.add("iso")
             self._searched_locations.add("cdrom")
-        if CONF.config_drive_vfat:
+        if CONF.config_drive.vfat:
             self._searched_types.add("vfat")
             self._searched_locations.add("hdd")
 
