@@ -36,7 +36,7 @@ class ShellScriptPlugin(base.BaseUserDataPlugin):
         target_path = os.path.join(tempfile.gettempdir(), file_name)
 
         try:
-            encoding.write_file(target_path, part.get_payload())
+            encoding.write_file(target_path, part.get_payload(decode=True))
 
             return fileexecutils.exec_file(target_path)
         except Exception as ex:
