@@ -76,6 +76,11 @@ class TestWindowsConfigDriveManager(unittest.TestCase):
         if exists and not fail:
             self.assertEqual(["Config Drive found on C:\\"],
                              self.snatcher.output)
+        if not label:
+            self.assertEqual(["Looking for a Config Drive with label "
+                              "'config-2' on 'C:\\'. Found mismatching "
+                              "label 'None'."],
+                             self.snatcher.output)
         self.assertEqual(not fail, response)
 
     def test_check_for_config_drive_exists(self):
@@ -90,6 +95,10 @@ class TestWindowsConfigDriveManager(unittest.TestCase):
     def test_check_for_config_drive_wrong_label(self):
         self._test_check_for_config_drive(label="config-3", fail=True)
 
+    def test_check_for_config_drive_empty_label(self):
+        self._test_check_for_config_drive(label=None, exists=False,
+                                          fail=True)
+
     def _test_get_iso_file_size(self, fixed=True, small=False,
                                 found_iso=True):
         device = mock.Mock()
@@ -394,6 +403,14 @@ class TestWindowsConfigDriveManager(unittest.TestCase):
         self._test__get_config_drive_files(
             "iso", "cdrom", func)
 
+    @mock.patch('cloudbaseinit.metadata.services.osconfigdrive.windows.'
+                'WindowsConfigDriveManager.'
+                '_get_config_drive_from_cdrom_drive')
+    def test__get_config_drive_files_cdrom_iso_failed(self, func):
+        func.side_effect = Exception
+        self._test__get_config_drive_files(
+            "iso", "cdrom", func, found=False)
+
     def test__get_config_drive_files_cdrom_vfat(self):
         self._test__get_config_drive_files(
             "vfat", "cdrom", None)
